@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.1502';
+our $VERSION = '0.1503';
 
 use Moo;
 use strictures 2;
@@ -316,7 +316,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.1502
+version 0.1503
 
 =head1 SYNOPSIS
 
@@ -350,6 +350,12 @@ A C<Lingua::EN::Opinion> object measures the emotional sentiment of
 text and saves the results in the B<scores> and B<nrc_scores>
 attributes.
 
+When run against the positive and negative classified training reviews
+in the dataset referenced under L</"SEE ALSO">, this module does ...
+okay.  Out of the 12.5k positive reviews, the F<eg/pos-neg> program
+gets 70% correct.  Out of the same number of negative reviews, the
+program gets 74% correct.
+
 =head1 ATTRIBUTES
 
 =head2 file
@@ -366,7 +372,7 @@ Boolean flag to indicate that word stemming should take place.
 
 For example, "horses" becomes "horse" and "hooves" becomes "hoof."
 
-This is the proper way to use this module.
+This is the proper way to use this module but takes ... a lot longer.
 
 =head2 stemmer
 
@@ -526,6 +532,8 @@ L<http://saifmohammad.com/WebPages/NRC-Emotion-Lexicon.htm>
 
 L<http://techn.ology.net/book-of-revelation-sentiment-analysis/> is a write-up using this technique.
 
+L<https://ai.stanford.edu/~amaas/data/sentiment/> is the "Large Movie Review Dataset"
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
